@@ -3,47 +3,34 @@ import itertools
 from collections import namedtuple
 from datetime import datetime
 from functools import wraps
-from typing import List, Iterable
-import os
-import os.path
+from typing import Iterable, List
+from subprocess import check_output
 
 from loguru import logger
 import pytz
 import requests
 
-__version__ = "0.1.16"
+from .mongo_tools import clean_json
+from .data_utils import to_dicts
+
+__version__ = "0.1.18"
 
 
-def pairwise(iterable):
-    """s -> (s0,s1), (s1,s2), (s2, s3), ..."""
-    a, b = itertools.tee(iterable)
-    next(b, None)
-    return zip(a, b)
+def logged_user(logger=logger):
+    def logging_user_wrapper(func):
+        function_name = func.__name__
 
+        @wraps(func)
+        def log(*args, **kwargs):
+            user = kwargs.get("current_user")
+            username = user.username if user else "Unknown User"
 
-def logged_user(func):
-    @wraps(func)
-    def log(*args, **kwargs):
-        logger.info(f"{kwargs['current_user'].username} ran {func.__name__}")
-        return func(*args, **kwargs)
+            logger.info(f"{username} ran {function_name}")
+            return func(*args, **kwargs)
 
-    return log
+        return log
 
-
-def clean_json(object_query):
-    ret = [o.to_mongo().to_dict() for o in object_query]
-    for r in ret:
-        if "_id" in r:
-            r["id"] = str(r["_id"])
-            del r["_id"]
-    return ret
-
-
-def to_dicts(ds):
-    if not ds:
-        return []
-    header = ds[0]
-    return [dict(zip(header, row)) for row in ds[1:]]
+    return logging_user_wrapper
 
 
 def parse_float(value: str):
@@ -102,13 +89,6 @@ def quick_search(query, model, fields=None, base_raw_query=None):
 GpsCoords = namedtuple("GpsCoords", "lat,lon")
 
 
-def counter(start=0, step=1):
-    count = start
-    while True:
-        yield count
-        count += step
-
-
 def build_send_slack_message(prefix, slack_webhook):
     def send_slack_message(message):
         from notifiers import get_notifier
@@ -158,6 +138,41 @@ def parse_csl(value, lower=True):
     :param lower: should we also lowercase everything (default true)
     :return: a list of strings
     """
+    value = value.strip()
+    if not value:
+        return []
     if lower:
         return [t.strip() for t in value.lower().strip().split(",")]
     return [t.strip() for t in value.strip().split(",")]
+
+
+def sorted_groupby(iterable, key, value=lambda x: x):
+    """
+    just like regular pythons regular group by except it sorts for you
+    :param iterable: the thing to iterate through
+    :param key: the key to both sort and group by
+    :param value: a function to apply to the group before returning (defaults to groupby iterator)
+    :return: iterable of tuples if (key_results, grouped_values)
+    """
+    return (
+        (k, value(v))
+        for k, v in itertools.groupby(sorted(iter(iterable), key=key), key=key)
+    )
+
+
+def counter(start=0, step=1):
+    count = start
+    while True:
+        yield count
+        count += step
+
+
+def pairwise(iterable: Iterable):
+    """s -> (s0,s1), (s1,s2), (s2, s3), ..."""
+    a, b = itertools.tee(iterable)
+    next(b, None)
+    return zip(a, b)
+
+
+def get_stdout_lines(command: List[str]) -> List[str]:
+    return check_output(command).decode().splitlines()
